@@ -33,9 +33,21 @@ from autopilot.input import (
     Keyboard,
     Pointer
 )
-from ubiquity_autopilot_tests.emulators import gtktoplevel
-from ubiquity_autopilot_tests.emulators.gtktoplevel import GtkWindow
 from ubiquity_autopilot_tests.emulators import AutopilotGtkEmulatorBase
+from ubiquity_autopilot_tests.emulators.gtkcontainers import (
+    GtkAlignment,
+    GtkBox,
+)
+from ubiquity_autopilot_tests.emulators.gtkcontrols import (
+    GtkButton,
+    GtkCheckButton,
+    GtkLabel,
+    GtkProgressBar,
+    GtkTreeView,
+)
+from ubiquity_autopilot_tests.emulators.gtktoplevel import (
+    GtkWindow,
+)
 from ubiquity_autopilot_tests.testcase import UbiquityTestCase
 from ubiquity_autopilot_tests.configs import english_label_conf
 from ubiquity_autopilot_tests.configs.partconfig import (
@@ -94,7 +106,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
 
     @property
     def main_window(self, ):
-        return self.app.select_single('GtkWindow', name='live_installer')
+        return self.app.select_single(GtkWindow, name='live_installer')
 
     def go_to_next_page(self, wait=False):
         """ Goes to the next page of Ubiquity installer
@@ -109,7 +121,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
 
         """
         logger.debug('go_to_next_page(wait={0})'.format(wait))
-        nxt_button = self.main_window.select_single('GtkButton', name='next')
+        nxt_button = self.main_window.select_single(GtkButton, name='next')
         nxt_button.click()
 
         if wait:
@@ -144,10 +156,10 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
                             Eventually(Equals(True), timeout=1200))
 
         page_title = self.main_window.select_single(
-            'GtkLabel', name='page_title')
+            GtkLabel, name='page_title')
         self.assertThat(page_title.label,
                         Eventually(NotEquals(self.current_page_title),
-                                   timeout=120))
+                                   timeout=240))
 
     def go_to_progress_page(self, ):
         """ This simply clicks next and goes to the progress page
@@ -157,7 +169,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
             checks.
 
         """
-        nxt_button = self.main_window.select_single('GtkButton', name='next')
+        nxt_button = self.main_window.select_single(GtkButton, name='next')
         nxt_button.click()
 
     def welcome_page_tests(self, lang=None):
@@ -178,8 +190,8 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         # selecting an install language
         logger.debug("Selecting stepLanguage page object")
         welcome_page = self.main_window.select_single(
-            'GtkBox', name='stepLanguage')
-        treeview = welcome_page.select_single('GtkTreeView')
+            GtkBox, name='stepLanguage')
+        treeview = welcome_page.select_single(GtkTreeView)
         # lets get all items
         treeview_items = treeview.get_all_items()
         # first lets check all the items are non-empty unicode strings
@@ -250,33 +262,27 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         logger.debug("run_preparing_page_tests()")
         logger.debug("selecting stepPrepare page")
         preparing_page = self.main_window.select_single(
-            'GtkAlignment', BuilderName='stepPrepare')
+            GtkAlignment, BuilderName='stepPrepare')
 
-        objList = ['prepare_best_results', 'prepare_foss_disclaimer',
-                   'prepare_download_updates', 'prepare_nonfree_software']
+        objList = [
+            'prepare_foss_disclaimer_license',
+            'prepare_download_updates',
+            'prepare_nonfree_software'
+        ]
         self.check_visible_object_with_label(objList)
 
         if updates:
             logger.debug("Selecting install updates")
             update_checkbutton = preparing_page.select_single(
-                'GtkCheckButton', BuilderName='prepare_download_updates')
+                GtkCheckButton, BuilderName='prepare_download_updates')
             self.pointing_device.click_object(update_checkbutton)
 
         if thirdParty:
             logger.debug("Selecting install thirdparty software")
             thrdprty_checkbutton = preparing_page.select_single(
-                'GtkCheckButton', BuilderName='prepare_nonfree_software')
+                GtkCheckButton, BuilderName='prepare_nonfree_software')
             self.pointing_device.click_object(thrdprty_checkbutton)
 
-        self._check_preparing_statebox('prepare_network_connection',
-                                       visible=networkConnection)
-        # and sufficient space
-        self._check_preparing_statebox('prepare_sufficient_space',
-                                       visible=sufficientSpace)
-        # and power source
-        self._check_preparing_statebox('prepare_power_source',
-                                       visible=powerSource)
-
         self._check_page_titles()
         self._check_navigation_buttons()
 
@@ -368,7 +374,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         self.check_visible_object_with_label(config.visible_options)
         self.check_hidden_object_with_label(config.hidden_options)
         install_type_page = self.main_window.select_single(
-            'GtkAlignment', BuilderName='stepPartAsk')
+            GtkAlignment, BuilderName='stepPartAsk')
         if option_name:
             obj = install_type_page.select_single(BuilderName=option_name)
             self.pointing_device.click_object(obj)
@@ -391,7 +397,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
                      .format(crypto_password))
         logger.debug('Selecting stepPartCrypto page object')
         crypto_page = self.main_window.select_single(
-            'GtkAlignment', BuilderName='stepPartCrypto')
+            GtkAlignment, BuilderName='stepPartCrypto')
 
         items = ['verified_crypto_label', 'crypto_label', 'crypto_description',
                  'crypto_warning', 'crypto_extra_label', 'crypto_extra_time',
@@ -420,8 +426,8 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         logger.debug("run_custom_partition_page_tests()")
         logger.debug("Selecting the stepPartAdvanced page object")
         custom_page = self.main_window.select_single(
-            'GtkAlignment', BuilderName='stepPartAdvanced')
-        treeview = custom_page.select_single('GtkTreeView')
+            GtkAlignment, BuilderName='stepPartAdvanced')
+        treeview = custom_page.select_single(GtkTreeView)
         self.expectThat(treeview.visible, Equals(True),
                         "[Page:'{0}'] Partition tree view was not visible")
         obj_list = ['partition_button_new', 'partition_button_delete',
@@ -469,7 +475,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
             partition_dialog.set_file_system_type(elem['FileSystemType'])
             partition_dialog.set_mount_point(elem['MountPoint'])
             ok_button = partition_dialog.select_single(
-                'GtkButton', BuilderName='partition_dialog_okbutton')
+                GtkButton, BuilderName='partition_dialog_okbutton')
             self.pointing_device.click_object(ok_button)
             self.assertThat(partition_dialog.visible,
                             Eventually(Equals(False)),
@@ -494,7 +500,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
 
         logger.debug("Selecting stepLocation page object")
         location_page = self.main_window.select_single(
-            'GtkBox', BuilderName='stepLocation')
+            GtkBox, BuilderName='stepLocation')
         location_map = location_page.select_single('CcTimezoneMap')
         self.assertThat(location_map.visible, Equals(True),
                         "Expected location map to be visible but it wasn't")
@@ -521,9 +527,9 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
 
         logger.debug("Selecting the stepKeyboardCOnf page object")
         keyboard_page = self.main_window.select_single(
-            'GtkAlignment',
+            GtkAlignment,
             BuilderName='stepKeyboardConf')
-        treeviews = keyboard_page.select_many('GtkTreeView')
+        treeviews = keyboard_page.select_many(GtkTreeView)
         # lets check all the keyboard tree items for the selected language
         # TODO: we should probably test at some point try changing the keyboard
         #       layout to a different language/locale/layout and see if
@@ -590,7 +596,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         self._update_page_titles()
         logger.debug("Selecting stepUserInfo page")
         user_info_page = self.main_window.select_single(
-            'GtkBox',
+            GtkBox,
             BuilderName='stepUserInfo')
 
         objects = ['hostname_label', 'username_label', 'password_label',
@@ -634,7 +640,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         # self.expectThat(webkitwindow.visible, Equals(True))
         # print("Webkit window found and is visible")
         print("Selecting Progress bar")
-        progress_bar = self.main_window.select_single('GtkProgressBar',
+        progress_bar = self.main_window.select_single(GtkProgressBar,
                                                       name='install_progress')
 
         # Copying files progress bar
@@ -643,8 +649,9 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
               "progressbar")
         self._track_install_progress()
         print("First loop complete waiting for pbar to go back to 0")
+        # CI VM infrastructure can be a bit slow, hence long timeout.
         self.assertThat(progress_bar.fraction, Eventually(
-            Equals(0.0), timeout=180))
+            Equals(0.0), timeout=530))
         print("Now entering the second loop...........")
         # And now the install progress bar
         self._track_install_progress()
@@ -728,7 +735,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         logger.debug("_track_install_progress_bar()")
         print("_track_install_progress()")
         print("selecting progress bar")
-        progress_bar = self.main_window.select_single('GtkProgressBar',
+        progress_bar = self.main_window.select_single(GtkProgressBar,
                                                       name='install_progress')
         progress = 0.0
         while progress < 1.0:
@@ -796,7 +803,7 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
             pass
 
     def _get_dialog_message(self, dlg_object):
-        dialog_labels = dlg_object.select_many('GtkLabel')
+        dialog_labels = dlg_object.select_many(GtkLabel)
         message = ''
         for gtklabel in dialog_labels:
             # only add labels longer than 'Continue' so we avoid button labels
@@ -809,9 +816,9 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         """ adds a new partition """
         logger.debug("_add_new_partition()")
         custom_page = self.main_window.select_single(
-            'GtkAlignment',
+            GtkAlignment,
             BuilderName='stepPartAdvanced')
-        tree_view = custom_page.select_single('GtkTreeView')
+        tree_view = custom_page.select_single(GtkTreeView)
         item = tree_view.select_item(u'  free space')
         self.pointing_device.click_object(item)
         self.assertThat(item.selected, Equals(True),
@@ -829,9 +836,9 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         """
         logger.debug("Checking partition was created.....")
         custom_page = self.main_window.select_single(
-            'GtkAlignment',
+            GtkAlignment,
             BuilderName='stepPartAdvanced')
-        tree_view = custom_page.select_single('GtkTreeView')
+        tree_view = custom_page.select_single(GtkTreeView)
         # assert a new row has been added to the partition table
         total_rows = self._update_table_row_count(config)
         logger.debug("TOTAL NUMBER OF ROWS: {0}".format(self.part_table_rows))
@@ -904,16 +911,16 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         logger.debug("check_window_constants({0}, {1}, {2}, {3})".format(
             continue_button, back_button, quit_button, skip_button))
 
-        con_button = self.main_window.select_single('GtkButton', name='next')
+        con_button = self.main_window.select_single(GtkButton, name='next')
         self.assertThat(con_button.visible, Equals(continue_button))
 
-        bk_button = self.main_window.select_single('GtkButton', name='back')
+        bk_button = self.main_window.select_single(GtkButton, name='back')
         self.assertThat(bk_button.visible, Equals(back_button))
 
-        qt_button = self.main_window.select_single('GtkButton', name='quit')
+        qt_button = self.main_window.select_single(GtkButton, name='quit')
         self.assertThat(qt_button.visible, Equals(quit_button))
 
-        skp_button = self.main_window.select_single('GtkButton', name='skip')
+        skp_button = self.main_window.select_single(GtkButton, name='skip')
         self.assertThat(skp_button.visible, Equals(skip_button))
 
     def _update_current_step(self, name):
@@ -927,9 +934,9 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         " Returns number of rows in table"
 
         custom_page = self.main_window.select_single(
-            'GtkAlignment',
+            GtkAlignment,
             BuilderName='stepPartAdvanced')
-        tree_view = custom_page.select_single('GtkTreeView')
+        tree_view = custom_page.select_single(GtkTreeView)
         num = tree_view.get_number_of_rows()
         if num == self.total_number_partitions:
             # TODO: assert 'free space' changes to a partition
@@ -960,12 +967,12 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
     def _update_page_titles(self, ):
         self.previous_page_title = self.current_page_title
         self.current_page_title = self.main_window.select_single(
-            'GtkLabel',
+            GtkLabel,
             BuilderName='page_title').label
 
     def _check_page_titles(self, ):
         current_page_title = self.main_window.select_single(
-            'GtkLabel',
+            GtkLabel,
             BuilderName='page_title')
         if self.current_step in self.english_config:
             if self.english_install and (
@@ -1002,45 +1009,6 @@ class UbiquityAutopilotTestCase(UbiquityTestCase):
         #                     "[Page:'{0}'] Expect page title to be visible "
         #                     "but it wasn't".format(self.current_step))
 
-    def _check_preparing_statebox(self, stateboxName, visible=True,
-                                  imagestock='gtk-yes'):
-        """ Checks the preparing page statebox's """
-        logger.debug("Running checks on {0} StateBox".format(stateboxName))
-        preparing_page = self.main_window.select_single(
-            'GtkAlignment', BuilderName='stepPrepare')
-        state_box = preparing_page.select_single(
-            'StateBox', BuilderName=stateboxName)
-        logger.debug('check({0}, {1})'.format(visible, imagestock))
-        logger.debug("Running checks.......")
-        if visible:
-            self.expectThat(state_box.visible, Equals(visible),
-                            "StateBox.check(): Expected {0} statebox to be "
-                            "visible but it wasn't"
-                            .format(state_box.name))
-            label = state_box.select_single('GtkLabel')
-            self.expectThat(label.label, NotEquals(u''),
-                            "[Page:'{0}'] Expected {1} Statebox's label to "
-                            "contain text but it didn't"
-                            .format(self.current_step, stateboxName))
-            self.expectThat(label.visible, Equals(visible),
-                            "[Page:'{0}'] Expected {1} Statebox label's "
-                            "visible property to be {2} "
-                            .format(self.current_step, stateboxName,
-                                    str(visible)))
-            self.expectIsInstance(label.label, str,
-                                  "[Page:'{0}'] Expected {1} Statebox's label "
-                                  "to be unicode but it wasn't"
-                                  .format(self.current_step, stateboxName))
-            image = state_box.select_single('GtkImage')
-            self.expectThat(image.stock, Equals(imagestock))
-            self.expectThat(image.visible, Equals(visible))
-
-        else:
-            self.expectThat(state_box.visible, Equals(False),
-                            "[Page:'{0}'] Expected {1} statebox to not be "
-                            "visible but it was"
-                            .format(self.current_step, stateboxName))
-
     def get_distribution(self, ):
         """Returns the name of the running distribution."""
         logger.debug("Detecting flavor")
