@@ -459,7 +459,7 @@ int netcfg_activate_dhcp (struct debconfclient *client, struct netcfg_interface
     kill_dhcp_client();
     loop_setup();
     
-    interface_up(interface->name);
+    netcfg_interface_up(interface);
 
     for (;;) {
         di_debug("State is now %i", state);
@@ -614,7 +614,9 @@ int netcfg_activate_dhcp (struct debconfclient *client, struct netcfg_interface
                 netcfg_write_loopback();
                 netcfg_write_interface(interface);
                 netcfg_write_resolv(domain, interface);
+#if !defined(__FreeBSD_kernel__)
                 kill_dhcp_client();
+#endif
                 stop_rdnssd();
 
                 return 0;
@@ -709,14 +711,15 @@ int netcfg_dhcp(struct debconfclient *client, struct netcfg_interface *interface
     if (!have_domain && (d = fopen(DOMAIN_FILE, "r")) != NULL) {
         di_debug("Reading domain name returned via DHCP");
         domain[0] = '\0';
-        if (fgets(domain, sizeof(domain), d) != NULL)
+        while (fgets(domain, sizeof(domain), d) != NULL) {
             rtrim(domain);
+            di_debug("DHCP domain name is '%s'", domain);
+            if (!empty_str(domain)) {
+                have_domain = 1;
+            }
+        }
         fclose(d);
         unlink(DOMAIN_FILE);
-        di_debug("DHCP domain name is '%s'", domain);
-        if (!empty_str(domain)) {
-            have_domain = 1;
-        }
     }
 
     /*
@@ -729,8 +732,9 @@ int netcfg_dhcp(struct debconfclient *client, struct netcfg_interface *interface
         
         di_debug("Reading NTP servers from DHCP info");
         
-        if (fgets(ntpservers, DHCP_OPTION_LEN, d) != NULL)
+        while (fgets(ntpservers, DHCP_OPTION_LEN, d) != NULL) {
             rtrim(ntpservers);
+        }
         fclose(d);
         unlink(NTP_SERVER_FILE);
 
