@@ -2,7 +2,7 @@
 
 import os
 
-from PyQt4 import QtCore
+from PyQt5 import QtCore
 
 from ubiquity import i18n
 
@@ -63,7 +63,7 @@ class PartitionModel(QtCore.QAbstractItemModel):
     def setData(self, index, value, role):
         item = index.internalPointer()
         if role == QtCore.Qt.CheckStateRole and index.column() == 3:
-            item.partman_column_format_toggled(value.toBool())
+            item.partman_column_format_toggled(value)
         self.emit(
             QtCore.SIGNAL(
                 "dataChanged(const QModelIndex&, const QModelIndex&)"),
