@@ -374,8 +374,13 @@ def grub_default(boot=None):
             else:
                 # Try the next disk along (which can't also be the CD source).
                 target = os.path.realpath(devices[1].split('\t')[1])
-            target = re.sub(r'(/dev/(cciss|ida)/c[0-9]d[0-9]|/dev/[a-z]+).*',
-                            r'\1', target)
+            # Match the more specific patterns first, then move on to the more
+            # generic /dev/[a-z]+.
+            target = re.sub(r'(\
+                            /dev/(cciss|ida)/c[0-9]d[0-9]|\
+                            /dev/nvme[0-9]+n[0-9]+|\
+                            /dev/[a-z]+\
+                            ).*', r'\1', target)
         except (IndexError, OSError):
             pass
 
@@ -824,7 +829,7 @@ def has_connection():
     import dbus
     bus = dbus.SystemBus()
     manager = bus.get_object(NM, '/org/freedesktop/NetworkManager')
-    state = get_prop(manager, NM, 'state')
+    state = get_prop(manager, NM, 'State')
     return state == NM_STATE_CONNECTED_GLOBAL
 
 
