@@ -23,10 +23,8 @@ from __future__ import print_function
 import os
 import re
 
-from ubiquity import plugin
-from ubiquity import keyboard_names
-from ubiquity import misc
-from ubiquity import osextras
+from ubiquity import keyboard_names, misc, osextras, plugin
+
 
 NAME = 'console_setup'
 AFTER = 'timezone'
@@ -68,6 +66,13 @@ class PageGtk(plugin.PluginUI):
         test_label = self.controller.get_string('keyboard_test_label', lang)
         self.keyboard_test.set_placeholder_text(test_label)
 
+    def cancel_timeouts(self):
+        from gi.repository import GLib
+        if self.keyboard_layout_timeout_id:
+            GLib.source_remove(self.keyboard_layout_timeout_id)
+        if self.keyboard_variant_timeout_id:
+            GLib.source_remove(self.keyboard_variant_timeout_id)
+
     @plugin.only_this_page
     def calculate_result(self, w, keymap):
         l = self.controller.dbfilter.get_locale()
@@ -95,7 +100,7 @@ class PageGtk(plugin.PluginUI):
         self.query = KeyboardQuery(self.controller._wizard)
         self.query.connect('layout_result', self.calculate_result)
         self.query.connect('delete-event', self.calculate_closed)
-        #self.controller._wizard.overlay.set_property('greyed', True)
+        # self.controller._wizard.overlay.set_property('greyed', True)
         self.query.set_transient_for(self.page.get_toplevel())
         self.query.run()
 
@@ -257,8 +262,8 @@ class PageKde(plugin.PluginUI):
         self.default_keyboard_variant = None
 
         try:
-            from PyQt4 import uic
-            from PyQt4.QtGui import QVBoxLayout
+            from PyQt5 import uic
+            from PyQt5.QtWidgets import QVBoxLayout
             from ubiquity.frontend.kde_components.Keyboard import Keyboard
 
             self.page = uic.loadUi(
@@ -281,19 +286,22 @@ class PageKde(plugin.PluginUI):
     @plugin.only_this_page
     def on_keyboard_layout_selected(self, *args):
         layout = self.get_keyboard()
-        l = self.controller.dbfilter.get_locale()
+        lang = self.controller.dbfilter.get_locale()
         if layout is not None:
-            #skip updating keyboard if not using display
-            if self.keyboardDisplay:
-                ly = keyboard_names.layout_id(l, misc.utf8(layout))
-                self.keyboardDisplay.setLayout(ly)
+                # skip updating keyboard if not using display
+                if self.keyboardDisplay:
+                    try:
+                        ly = keyboard_names.layout_id(lang, misc.utf8(layout))
+                    except KeyError:
+                        ly = keyboard_names.layout_id('C', misc.utf8(layout))
+                    self.keyboardDisplay.setLayout(ly)
 
-                #no variants, force update by setting none
-                #if not keyboard_names.has_variants(l, ly):
-                #    self.keyboardDisplay.setVariant(None)
+                    # no variants, force update by setting none
+                    # if not keyboard_names.has_variants(l, ly):
+                    #    self.keyboardDisplay.setVariant(None)
 
-            self.current_layout = layout
-            self.controller.dbfilter.change_layout(layout)
+                self.current_layout = layout
+                self.controller.dbfilter.change_layout(layout)
 
     @plugin.only_this_page
     def on_keyboard_variant_selected(self, *args):
@@ -302,11 +310,15 @@ class PageKde(plugin.PluginUI):
 
         if self.keyboardDisplay:
             var = None
-            l = self.controller.dbfilter.get_locale()
-            ly = keyboard_names.layout_id(l, layout)
+            lang = self.controller.dbfilter.get_locale()
+            try:
+                ly = keyboard_names.layout_id(lang, layout)
+            except KeyError:
+                ly = keyboard_names.layout_id('C', layout)
             if variant:
                 try:
-                    var = keyboard_names.variant_id(l, ly, misc.utf8(variant))
+                    var = keyboard_names.variant_id(lang, ly,
+                                                    misc.utf8(variant))
                 except KeyError:
                     var = None
 
@@ -331,8 +343,11 @@ class PageKde(plugin.PluginUI):
             self.page.keyboard_layout_combobox.setCurrentIndex(index)
 
         if self.keyboardDisplay:
-            l = self.controller.dbfilter.get_locale()
-            ly = keyboard_names.layout_id(l, misc.utf8(layout))
+            lang = self.controller.dbfilter.get_locale()
+            try:
+                ly = keyboard_names.layout_id(lang, misc.utf8(layout))
+            except KeyError:
+                ly = keyboard_names.layout_id('C', misc.utf8(layout))
             self.keyboardDisplay.setLayout(ly)
 
     def get_keyboard(self):
@@ -355,12 +370,15 @@ class PageKde(plugin.PluginUI):
             self.page.keyboard_variant_combobox.setCurrentIndex(index)
 
         if self.keyboardDisplay:
-            l = self.controller.dbfilter.get_locale()
-            layout = keyboard_names.layout_id(l, self.get_keyboard())
+            lang = self.controller.dbfilter.get_locale()
+            try:
+                layout = keyboard_names.layout_id(lang, self.get_keyboard())
+            except KeyError:
+                layout = keyboard_names.layout_id('C', self.get_keyboard())
             if variant:
                 try:
                     var = keyboard_names.variant_id(
-                        l, layout, misc.utf8(variant))
+                        lang, layout, misc.utf8(variant))
                 except KeyError:
                     var = None
 
@@ -526,7 +544,7 @@ class Page(plugin.Plugin):
                 self.description(question),
                 self.extended_description(question),
                 ('ubiquity/imported/yes', 'ubiquity/imported/no'))
-            if response is None or response == 'ubiquity/imported/yes':
+            if response == 'ubiquity/imported/yes':
                 self.preseed(question, 'true')
             else:
                 self.preseed(question, 'false')
@@ -542,10 +560,20 @@ class Page(plugin.Plugin):
         self.succeeded = False
         self.exit_ui_loops()
 
+    def cancel_handler(self):
+        if hasattr(self.ui, "cancel_timeouts"):
+            self.ui.cancel_timeouts()
+
+        return plugin.Plugin.cancel_handler(self)
+
     def ok_handler(self):
         variant = self.ui.get_keyboard_variant()
         if variant is not None:
             self.preseed('keyboard-configuration/variant', variant)
+
+        if hasattr(self.ui, "cancel_timeouts"):
+            self.ui.cancel_timeouts()
+
         return plugin.Plugin.ok_handler(self)
 
     # TODO cjwatson 2006-09-07: This is duplication from
