@@ -124,7 +124,9 @@ class PageGtk(PreparePageBase):
     def set_using_secureboot(self, secureboot):
         self.using_secureboot = secureboot
         self.secureboot_box.set_visible(secureboot)
+        self.disable_secureboot.set_active(True)
         self.on_nonfree_toggled(None)
+        self.info_loop(None)
 
     def enable_download_updates(self, val):
         if (val):
@@ -174,6 +176,7 @@ class PageGtk(PreparePageBase):
     def on_nonfree_toggled(self, widget):
         enabled = self.get_use_nonfree()
         self.secureboot_box.set_sensitive(enabled)
+        self.info_loop(None)
 
     def on_secureboot_toggled(self, widget):
         enabled = self.get_disable_secureboot()
@@ -181,6 +184,11 @@ class PageGtk(PreparePageBase):
         self.info_loop(None)
 
     def info_loop(self, unused_widget):
+        if not self.get_use_nonfree() \
+                or not self.password_grid.get_sensitive():
+            self.controller.allow_go_forward(True)
+            return True
+
         complete = False
         passw = self.password.get_text()
         vpassw = self.verified_password.get_text()
@@ -195,7 +203,10 @@ class PageGtk(PreparePageBase):
             self.password_strength.set_current_page(
                 self.password_strength_pages['too_short'])
 
-        if passw != vpassw or (passw and len(passw) < 8):
+        if len(passw) == 0 or len(vpassw) == 0:
+            self.password_match.set_current_page(
+                self.password_match_pages['empty'])
+        elif passw != vpassw or (passw and len(passw) < 8):
             self.password_match.set_current_page(
                 self.password_match_pages['empty'])
             if len(passw) >= 8 and (not passw.startswith(vpassw) or
@@ -241,8 +252,8 @@ class PageKde(PreparePageBase):
             return
         self.controller = controller
         try:
-            from PyQt4 import uic
-            from PyQt4 import QtGui
+            from PyQt5 import uic
+            from PyQt5 import QtGui
             self.page = uic.loadUi('/usr/share/ubiquity/qt/stepPrepare.ui')
             self.prepare_download_updates = self.page.prepare_download_updates
             self.prepare_nonfree_software = self.page.prepare_nonfree_software
@@ -318,7 +329,7 @@ class PageKde(PreparePageBase):
         self.prepare_download_updates.setChecked(val)
 
     def get_download_updates(self):
-        from PyQt4.QtCore import Qt
+        from PyQt5.QtCore import Qt
         return self.prepare_download_updates.checkState() == Qt.Checked
 
     def set_allow_nonfree(self, allow):
@@ -335,7 +346,7 @@ class PageKde(PreparePageBase):
             self.set_allow_nonfree(False)
 
     def get_use_nonfree(self):
-        from PyQt4.QtCore import Qt
+        from PyQt5.QtCore import Qt
         return self.prepare_nonfree_software.checkState() == Qt.Checked
 
     def plugin_translate(self, lang):
